@@ -17,6 +17,12 @@
 /* define if you have setenv */
 #undef HAVE_FUNC_SETENV
 
+/* define if you have fgetpwent */
+#undef HAVE_FGETPWENT
+
+/* define if you have fgetgrent */
+#undef HAVE_FGETGRENT
+
 /* Define to 1 if NLS is requested.  */
 #undef ENABLE_NLS
 
