@@ -257,7 +257,7 @@ bool KSVTopLevel::queryExit() {
 
   if (_changed) {
     res = KMsgBox::yesNo(kapp->mainWidget(),
-			 i18n("Quit"),
+			 i18n("Exit"),
 			 i18n("There are unsaved changes.\nAre you sure you want to quit?"),
 			 KMsgBox::QUESTION,
 			 i18n("Yes, quit!"),
